@@ -16,6 +16,7 @@ from requests.models import Response
 from localstack import config
 from localstack.constants import (
     APPLICATION_JSON,
+    HEADER_LOCALSTACK_AUTHORIZATION,
     HEADER_LOCALSTACK_EDGE_URL,
     LOCALHOST_HOSTNAME,
     PATH_USER_REQUEST,
@@ -531,6 +532,11 @@ def invoke_rest_api_integration_backend(invocation_context: ApiInvocationContext
     integration_type_orig = integration.get("type") or integration.get("integrationType") or ""
     integration_type = integration_type_orig.upper()
     uri = integration.get("uri") or integration.get("integrationUri") or ""
+    # XXX we need replace the internal Authorization header with an Authorization header set from
+    # the customer, even if it's empty that's what's expected in the integration.
+    custom_auth_header = invocation_context.headers.pop(HEADER_LOCALSTACK_AUTHORIZATION, "")
+    invocation_context.headers["Authorization"] = custom_auth_header
+
     try:
         path_params = extract_path_params(path=relative_path, extracted_path=resource_path)
         invocation_context.path_params = path_params
