@@ -58,13 +58,13 @@ def cloudwatch():
 
 @aws_provider()
 def dynamodb():
-    from localstack.services.dynamodb import dynamodb_listener, dynamodb_starter
+    from localstack.services.dynamodb.provider import DynamoDBApiListener
 
+    listener = DynamoDBApiListener()
     return Service(
         "dynamodb",
-        listener=dynamodb_listener.UPDATE_DYNAMODB,
-        start=dynamodb_starter.start_dynamodb,
-        check=dynamodb_starter.check_dynamodb,
+        listener=listener,
+        lifecycle_hook=listener.provider,
     )
 
 
@@ -140,7 +140,7 @@ def kinesis():
 
 @aws_provider()
 def kms():
-    if config.KMS_PROVIDER == "kms-local":
+    if config.KMS_PROVIDER == "local-kms":
         from localstack.services.kms import kms_starter
 
         return Service("kms", start=kms_starter.start_kms_local)
@@ -164,6 +164,16 @@ def awslambda():
     )
 
 
+@aws_provider(api="lambda", name="asf")
+def awslambda_asf():
+    from localstack.aws.proxy import AwsApiListener
+    from localstack.services.awslambda.provider import LambdaProvider
+
+    provider = LambdaProvider()
+
+    return Service("lambda", listener=AwsApiListener("lambda", provider), lifecycle_hook=provider)
+
+
 @aws_provider()
 def logs():
     from localstack.services.logs.provider import LogsAwsApiListener
