@@ -11,8 +11,8 @@ from docker.errors import APIError, ContainerError, DockerException, ImageNotFou
 from docker.models.containers import Container
 from docker.utils.socket import STDERR, STDOUT, frames_iter
 
-from localstack.utils.common import start_worker_thread, to_bytes
 from localstack.utils.container_utils.container_client import (
+    AccessDenied,
     ContainerClient,
     ContainerException,
     DockerContainerStatus,
@@ -20,10 +20,12 @@ from localstack.utils.container_utils.container_client import (
     NoSuchImage,
     NoSuchNetwork,
     PortMappings,
+    RegistryConnectionError,
     SimpleVolumeBind,
     Util,
 )
-from localstack.utils.run import to_str
+from localstack.utils.strings import to_bytes, to_str
+from localstack.utils.threads import start_worker_thread
 
 LOG = logging.getLogger(__name__)
 SDK_ISDIR = 1 << 31
@@ -120,6 +122,16 @@ class SdkDockerClient(ContainerClient):
         except APIError:
             raise ContainerException()
 
+    def unpause_container(self, container_name: str) -> None:
+        LOG.debug("Unpausing container: %s", container_name)
+        try:
+            container = self.client().containers.get(container_name)
+            container.unpause()
+        except NotFound:
+            raise NoSuchContainer(container_name)
+        except APIError:
+            raise ContainerException()
+
     def remove_container(self, container_name: str, force=True, check_existence=False) -> None:
         LOG.debug("Removing container: %s", container_name)
         if check_existence and container_name not in self.get_running_container_names():
@@ -191,16 +203,57 @@ class SdkDockerClient(ContainerClient):
             raise ContainerException()
 
     def pull_image(self, docker_image: str) -> None:
-        LOG.debug("Pulling image: %s", docker_image)
+        LOG.debug("Pulling Docker image: %s", docker_image)
         # some path in the docker image string indicates a custom repository
         try:
-            LOG.debug("Repository: %s", docker_image)
             self.client().images.pull(docker_image)
         except ImageNotFound:
             raise NoSuchImage(docker_image)
         except APIError:
             raise ContainerException()
 
+    def push_image(self, docker_image: str) -> None:
+        LOG.debug("Pushing Docker image: %s", docker_image)
+        try:
+            result = self.client().images.push(docker_image)
+            # some SDK clients (e.g., 5.0.0) seem to return an error string, instead of raising
+            if isinstance(result, (str, bytes)) and '"errorDetail"' in to_str(result):
+                if "image does not exist locally" in to_str(result):
+                    raise NoSuchImage(docker_image)
+                if "is denied" in to_str(result):
+                    raise AccessDenied(docker_image)
+                if "connection refused" in to_str(result):
+                    raise RegistryConnectionError(result)
+                raise ContainerException(result)
+        except ImageNotFound:
+            raise NoSuchImage(docker_image)
+        except APIError as e:
+            raise ContainerException() from e
+
+    def build_image(self, dockerfile_path: str, image_name: str, context_path: str = None):
+        try:
+            dockerfile_path = Util.resolve_dockerfile_path(dockerfile_path)
+            context_path = context_path or os.path.dirname(dockerfile_path)
+            LOG.debug("Building Docker image %s from %s", image_name, dockerfile_path)
+            self.client().images.build(
+                path=context_path,
+                dockerfile=dockerfile_path,
+                tag=image_name,
+                rm=True,
+            )
+        except APIError as e:
+            raise ContainerException("Unable to build Docker image") from e
+
+    def tag_image(self, source_ref: str, target_name: str) -> None:
+        try:
+            LOG.debug("Tagging Docker image '%s' as '%s'", source_ref, target_name)
+            image = self.client().images.get(source_ref)
+            image.tag(target_name)
+        except APIError as e:
+            if e.status_code == 404:
+                raise NoSuchImage(source_ref)
+            raise ContainerException("Unable to tag Docker image") from e
+
     def get_docker_image_names(self, strip_latest=True, include_tags=True):
         try:
             images = self.client().images.list()
@@ -423,7 +476,8 @@ class SdkDockerClient(ContainerClient):
         ports: Optional[PortMappings] = None,
         env_vars: Optional[Dict[str, str]] = None,
         user: Optional[str] = None,
-        cap_add: Optional[str] = None,
+        cap_add: Optional[List[str]] = None,
+        cap_drop: Optional[List[str]] = None,
         network: Optional[str] = None,
         dns: Optional[str] = None,
         additional_flags: Optional[str] = None,
@@ -438,7 +492,9 @@ class SdkDockerClient(ContainerClient):
         try:
             kwargs = {}
             if cap_add:
-                kwargs["cap_add"] = [cap_add]
+                kwargs["cap_add"] = cap_add
+            if cap_drop:
+                kwargs["cap_drop"] = cap_drop
             if dns:
                 kwargs["dns"] = [dns]
             if ports:
@@ -494,7 +550,8 @@ class SdkDockerClient(ContainerClient):
         ports: Optional[PortMappings] = None,
         env_vars: Optional[Dict[str, str]] = None,
         user: Optional[str] = None,
-        cap_add: Optional[str] = None,
+        cap_add: Optional[List[str]] = None,
+        cap_drop: Optional[List[str]] = None,
         network: Optional[str] = None,
         dns: Optional[str] = None,
         additional_flags: Optional[str] = None,
@@ -517,6 +574,7 @@ class SdkDockerClient(ContainerClient):
                 env_vars=env_vars,
                 user=user,
                 cap_add=cap_add,
+                cap_drop=cap_drop,
                 network=network,
                 dns=dns,
                 additional_flags=additional_flags,
@@ -542,6 +600,7 @@ class SdkDockerClient(ContainerClient):
         env_vars: Optional[Dict[str, Optional[str]]] = None,
         stdin: Optional[bytes] = None,
         user: Optional[str] = None,
+        workdir: Optional[str] = None,
     ) -> Tuple[bytes, bytes]:
         LOG.debug("Executing command in container %s: %s", container_name_or_id, command)
         try:
@@ -556,6 +615,7 @@ class SdkDockerClient(ContainerClient):
                 stdout=True,
                 stderr=True,
                 demux=True,
+                workdir=workdir,
             )
             tty = False
             if interactive and stdin:  # result is a socket
